@@ -75,7 +75,7 @@ func (p *emptyProvisioner) PowerOn() (provisioner.Result, error) {
 
 // PowerOff ensures the server is powered off independently of any image
 // provisioning operation.
-func (p *emptyProvisioner) PowerOff() (provisioner.Result, error) {
+func (p *emptyProvisioner) PowerOff(rebootMode metal3v1alpha1.RebootMode) (provisioner.Result, error) {
 	return provisioner.Result{}, nil
 }
 
